{% extends "horizon/common/_modal_form.html" %}
{% load i18n %}

{% block modal-body-right %}
  <h3>{% trans "Description:" %}</h3>
  <p>{% trans "Edit the mapping's details." %}</p>
  <p>{% trans "A rule contains a remote attribute description and the destination local attribute." %}</p>
{% endblock %}
